@@ -3,7 +3,12 @@ from subprocess import check_call, check_output
 from tempfile import TemporaryDirectory
 import logging
 
-from packaging.tags import sys_tags
+try:
+    from packaging.tags import sys_tags
+except ImportError as e:
+    err = "You need the 'build' extra option to use this build module.\n"
+    err += "For this you can install the 'cmeel[build]' package."
+    raise ImportError(err) from e
 import tomli
 
 from .consts import CMEEL_PREFIX
@@ -11,10 +16,6 @@ from .config import cmeel_config
 from . import __version__
 
 
-def get_deps():
-    return ["cmeel"]  # TODO
-
-
 def build_wheel(wheel_directory, config_settings=None, metadata_directory=None):
     logging.info("CMake Wheel")
 
@@ -26,7 +27,9 @@ def build_wheel(wheel_directory, config_settings=None, metadata_directory=None):
 
     logging.info("load conf from pyproject.toml")
     with open("pyproject.toml", "rb") as f:
-        CONF = tomli.load(f)["project"]
+        pyproject = tomli.load(f)
+        CONF = pyproject["project"]
+        SOURCE = pyproject["build-system"].get("source", ".")
     DISTRIBUTION = CONF["name"].replace("-", "_")
 
     logging.info("build wheel")
@@ -36,7 +39,7 @@ def build_wheel(wheel_directory, config_settings=None, metadata_directory=None):
     logging.info("configure")
     configure_args = cmeel_config.get_configure_args(CONF["name"], INSTALL)
     configure_env = cmeel_config.get_configure_env(CONF["name"])
-    check_call(["cmake", "-S", ".", "-B", BUILD] + configure_args, env=configure_env)
+    check_call(["cmake", "-S", SOURCE, "-B", BUILD] + configure_args, env=configure_env)
 
     logging.info("build")
     check_call(["cmake", "--build", BUILD])
@@ -56,7 +59,8 @@ def build_wheel(wheel_directory, config_settings=None, metadata_directory=None):
     logging.info("create dist-info / METADATA")
     with open(CONF["readme"]) as f:
         readme = f.read()
-    requires = "\n".join([f"Requires-Dist: {dep}" for dep in get_deps()])
+    dependencies = ["cmeel"] + CONF.get("dependencies", [])
+    requires = "\n".join([f"Requires-Dist: {dep}" for dep in dependencies])
     with (dist_info / "METADATA").open("w") as f:
         if CONF["readme"].lower().endswith(".md"):
             content_type = "text/markdown"
